@@ -1,23 +1,9 @@
-#
-# This file is part of MouseX-App-Cmd
-#
-# This software is copyright (c) 2011 by Infinity Interactive.
-#
-# This is free software; you can redistribute it and/or modify it under
-# the same terms as the Perl 5 programming language system itself.
-#
+package MouseX::App::Cmd::Command;
 use 5.006;
 use strict;
 use warnings;
 
-package MouseX::App::Cmd::Command;
-
-BEGIN {
-    $MouseX::App::Cmd::Command::VERSION = '0.08';
-}
-
-# ABSTRACT: Base class for commands.
-
+our $VERSION = '0.10';    # VERSION
 use Mouse;
 use English '-no_match_vars';
 use Getopt::Long::Descriptive ();
@@ -85,11 +71,15 @@ sub _usage_format {    ## no critic (ProhibitUnusedPrivateSubroutines)
 
 1;
 
+# ABSTRACT: Base class for commands.
+
 __END__
 
 =pod
 
-=for :stopwords Yuval Kogman Guillermo Roditi Mark Gardner Infinity Interactive
+=for :stopwords Yuval Kogman Guillermo Roditi Mark Gardner Infinity Interactive cpan
+testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto
+metadata placeholders metacpan
 
 =head1 NAME
 
@@ -97,7 +87,7 @@ MouseX::App::Cmd::Command - Base class for commands.
 
 =head1 VERSION
 
-version 0.08
+version 0.10
 
 =head1 SYNOPSIS
 
@@ -143,14 +133,94 @@ L<MouseX::Getopt|MouseX::Getopt> based processing.
 
 =back
 
-=head1 BUGS
+=head1 SUPPORT
 
-Please report any bugs or feature requests on the bugtracker website
-http://github.com/mjg/MouseX-App-Cmd/issues
+=head2 Perldoc
 
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
+You can find documentation for this module with the perldoc command.
+
+  perldoc MouseX::App::Cmd
+
+=head2 Websites
+
+The following websites have more information about this module, and may be of help to you. As always,
+in addition to those websites please use your favorite search engine to discover more resources.
+
+=over 4
+
+=item *
+
+Search CPAN
+
+The default CPAN search engine, useful to view POD in HTML format.
+
+L<http://search.cpan.org/dist/MouseX-App-Cmd>
+
+=item *
+
+AnnoCPAN
+
+The AnnoCPAN is a website that allows community annotations of Perl module documentation.
+
+L<http://annocpan.org/dist/MouseX-App-Cmd>
+
+=item *
+
+CPAN Ratings
+
+The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
+
+L<http://cpanratings.perl.org/d/MouseX-App-Cmd>
+
+=item *
+
+CPANTS
+
+The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
+
+L<http://cpants.perl.org/dist/overview/MouseX-App-Cmd>
+
+=item *
+
+CPAN Testers
+
+The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
+
+L<http://www.cpantesters.org/distro/M/MouseX-App-Cmd>
+
+=item *
+
+CPAN Testers Matrix
+
+The CPAN Testers Matrix is a website that provides a visual overview of the test results for a distribution on various Perls/platforms.
+
+L<http://matrix.cpantesters.org/?dist=MouseX-App-Cmd>
+
+=item *
+
+CPAN Testers Dependencies
+
+The CPAN Testers Dependencies is a website that shows a chart of the test results of all dependencies for a distribution.
+
+L<http://deps.cpantesters.org/?module=MouseX::App::Cmd>
+
+=back
+
+=head2 Bugs / Feature Requests
+
+Please report any bugs or feature requests through the web
+interface at L<https://github.com/mjgardner/mousex-app-cmd/issues>. You will be automatically notified of any
+progress on the request by the system.
+
+=head2 Source Code
+
+The code is open to the world, and available for you to hack on. Please feel free to browse it and play
+with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
+from your repository :)
+
+L<https://github.com/mjgardner/mousex-app-cmd>
+
+  git clone git://github.com/mjgardner/mousex-app-cmd.git
 
 =head1 AUTHORS
 
@@ -172,7 +242,7 @@ Mark Gardner <mjgardner@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Infinity Interactive.
+This software is copyright (c) 2012 by Infinity Interactive.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
